/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.utils
 * File:    LinkedMap.java
 *
 * Copyright (C) 2010-2011 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.utils;

import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedList;

/**
 * LinkedMap 
 * 
 * @author vp
 * @version 0.1
 * created: 01.12.09
 * changes:
 *  09.02.10 aw - values() returns a Collection<E>
 */
public class LinkedMap<E> {
	private HashMap<Integer,LinkedList<E>> elements = new HashMap<Integer,LinkedList<E>>();

	/**
	 * Return the LinkedList with elements for the key.
	 * @param key
	 * @return
	 */
	public LinkedList<E> get(int key) {
		LinkedList<E> list = elements.get(key);
		return list;
	}

	/**
	 * If the map contained a mapping for the key, the new value is
	 * added to old.
	 * @param key
	 * @param element
	 */
	public void put(int key, E element) {
		LinkedList<E> list = elements.get(key);
		if (list == null) {
			list = new LinkedList<E>();
			elements.put(key, list);
		}
		
		if (!list.contains(element)) {
			list.add(element);
		}
	}

	/**
	 * Removed element from LinkedList for specified key.
	 * @param key
	 * @param element
	 */
	public void remove(int key, E element) {
		LinkedList<E> list = get(key);
		if (list != null) {
			Object[] tempList = list.toArray();
			for (int i=0;i < tempList.length;i++) {
				if (tempList[i].equals(element)) {
					list.remove(element);
				}
			}
			if (list.isEmpty()) {
				list = null;
			}
		}
	}

	/**
	 * Removed all elements for specified key from this map
	 * if present.
	 * @param key
	 */
	public void removeAll(int key) {
		elements.remove(key);
	}

	/**
	 * Return reference to the element in the map.
	 * @param key
	 * @param element
	 * @return
	 */
	public E getElement(int key, E element) {
		if (elements.containsKey(key)) {
			for(E tempElem:elements.get(key)) {
				if(tempElem.equals(element)) {
					return tempElem;
				}
			}
		}
		return null;
	}
	
	public Collection<E> values() {
		Collection<E> ret = new LinkedList<E>();
		for (LinkedList<E> l : elements.values()) {
			for (E e : l) {
				ret.add(e);
			}
		}
		return ret;
	}
	
	public int size(){
		return elements.size();
	}
}
